/*
 * PrintSummaryListener.java
 *  
 * Copyright 2008 C.A. Meijer
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jmunit.anttask.cldc10;

import jmunit.framework.cldc10.AssertionFailedException;
import jmunit.framework.cldc10.TestListener;

/**
 * The PrintSummaryListener is a JMUnit <code>TestListener</code> that prints
 * test results to the console.
 * 
 * @author C.A. Meijer
 * @since JMUnit 1.1
 */
public class PrintSummaryListener implements TestListener {

	// The number of tests in the test suite.
	private int numTests;

	// The number of completed tests.
	private int numTestsCompleted;

	// The number of errors reported.
	private int numErrors;

	// The number of failures reported.
	private int numFailures;

	// The time at which the test suite started running.
	private long startTime;

	/**
	 * Constructor.
	 * 
	 * @param test The test suite.
	 */
	public PrintSummaryListener(jmunit.framework.cldc10.Test test) {
		System.out.println("Running " + test.getClass().getName());
		this.numTests = test.countTestCases();
		this.startTime = System.currentTimeMillis();
	}

	public void startTest(Class arg0, String arg1) {
	}

	/**
	 * Error reported.
	 * 
	 * @param testClass The test that reported an error.
	 * 
	 * @param testName The name of the test.
	 * 
	 * @param t The error.
	 */
	public void addError(Class testClass, String testName, Throwable t) {
		this.numErrors++;
	}

	/**
	 * Failure reported.
	 * 
	 * @param testClass The test that reported a failure.
	 * 
	 * @param testName The name of the test.
	 * 
	 * @param t The failure.
	 */
	public void addFailure(Class testClass, String testName,
			AssertionFailedException t) {
		this.numFailures++;
	}

	public void clear() {
	}

	/**
	 * A test finished running.
	 * 
	 * @param testClass The test that finsihed..
	 * 
	 * @param testName The name of the test.
	 */
	public void endTest(Class testClass, String testName) {
		this.numTestsCompleted++;
		
		// If all tests have finished, print a summary.
		if (this.numTestsCompleted == this.numTests) {
			long time = System.currentTimeMillis() - this.startTime;
			double t = time / 1000.0;
			System.out.print("Tests run: " + this.numTestsCompleted + ", ");
			System.out.print("Failures: " + this.numFailures + ", ");
			System.out.print("Errors: " + this.numErrors + ", ");
			System.out.println("Time elapsed: " + t + " sec");
		}
	}
}
