package jmunit.framework.cldc10;

import j2meunit.framework.Test;
import j2meunit.framework.TestCase;
import j2meunit.framework.TestSuite;
import jmunit.framework.cldc10.mocks.MockTest;

import com.hammingweight.hammock.Hammock;

public class TestRunnerTest extends TestCase {

	// The OUT.
	private TestRunner testRunner;

	// The mocks.
	private Hammock hammock;

	private MockTest mockTest;

	public void setUp() {
		// Create the mocks.
		this.hammock = new Hammock();
		this.mockTest = AllTestsRunner.mockTest2;
		this.mockTest.setInvocationHandler(this.hammock);

		// Create the OUT.
		this.testRunner = AllTestsRunner.testRunner;
	}

	// Test that counting test cases calls the method on the wrapped class.
	public void testCountTestCases() {
		// Set the expectations.
		this.hammock.setExpectation(MockTest.MTHD_COUNT_TEST_CASES)
				.setReturnValue(new Integer(15));

		// Exercise.
		assertEquals(15, this.testRunner.countTestCases());

		// Verify.
		this.hammock.verify();
	}

	// Test that calling test invokes the test method on the wrapped class.
	public void testTest() {
		// Set the expectations.
		this.hammock.setExpectation(MockTest.MTHD_COUNT_TEST_CASES)
				.setReturnValue(new Integer(15)).setNumberInvocations(0, 1);
		this.hammock.setExpectation(MockTest.MTHD_RUN_$_TESTRESULT);

		// Exercise.
		this.testRunner.test();

		// Verify.
		this.hammock.verify();
	}

	public void runTest() throws Throwable {
		if (getName().equals("testCountTestCases")) {
			testCountTestCases();
		} else if (getName().equals("testTest")) {
			testTest();
		} else {
			fail("Unknown test: " + getName());
		}
	}

	public Test suite() {
		TestSuite suite = new TestSuite(this.getClass(), new String[] {
				"testCountTestCases", "testTest" });
		return suite;
	}
}
